@@ -11,7 +11,7 @@ use File::Monitor::Delta;
 
 use base qw(File::Monitor::Base);
 
-our $VERSION = '0.10';
+our $VERSION = '1.00';
 
 my @STAT_FIELDS;
 my @INFO_FIELDS;
@@ -19,168 +19,167 @@ my $CLASS;
 
 BEGIN {
 
-    @STAT_FIELDS = qw(
-      dev inode mode num_links uid gid rdev size atime mtime ctime
-      blk_size blocks
-    );
+  @STAT_FIELDS = qw(
+   dev inode mode num_links uid gid rdev size atime mtime ctime
+   blk_size blocks
+  );
 
-    @INFO_FIELDS = (
-        @STAT_FIELDS, qw(
-          error
-          )
-    );
+  @INFO_FIELDS = (
+    @STAT_FIELDS, qw(
+     error
+     )
+  );
 
-    no strict 'refs';
+  no strict 'refs';
 
-    # Accessors for info
-    for my $info ( @INFO_FIELDS ) {
-        *$info = sub {
-            my $self = shift;
-            croak "$info attribute is read-only" if @_;
-            return $self->{_info}->{$info};
-        };
-    }
+  # Accessors for info
+  for my $info ( @INFO_FIELDS ) {
+    *$info = sub {
+      my $self = shift;
+      croak "$info attribute is read-only" if @_;
+      return $self->{_info}->{$info};
+    };
+  }
 }
 
 sub owner {
-    my $self = shift;
-    croak "name attribute is read-only" if @_;
-    return $self->{owner};
+  my $self = shift;
+  croak "name attribute is read-only" if @_;
+  return $self->{owner};
 }
 
 sub name {
-    my $self = shift;
-    croak "name attribute is read-only" if @_;
-    return $self->owner->_make_absolute( $self->{name} );
+  my $self = shift;
+  croak "name attribute is read-only" if @_;
+  return $self->owner->_make_absolute( $self->{name} );
 }
 
 sub files {
-    my $self = shift;
-    croak "files attribute is read-only" if @_;
-    my $monitor = $self->owner;
-    return
-      map { $monitor->_make_absolute( $_ ) }
-      @{ $self->{_info}->{files} || [] };
+  my $self = shift;
+  croak "files attribute is read-only" if @_;
+  my $monitor = $self->owner;
+  return
+   map { $monitor->_make_absolute( $_ ) }
+   @{ $self->{_info}->{files} || [] };
 }
 
 sub _initialize {
-    my $self = shift;
-    my $args = shift;
+  my $self = shift;
+  my $args = shift;
 
-    # Normalize the args
+  # Normalize the args
 
-    $self->SUPER::_initialize( $args );
-    $self->_install_callbacks( $args );
+  $self->SUPER::_initialize( $args );
+  $self->_install_callbacks( $args );
 
-    $self->{_info}->{virgin} = 1;
+  $self->{_info}->{virgin} = 1;
 
-    my $name = delete $args->{name}
-      or croak "The name option must be supplied";
+  my $name = delete $args->{name}
+   or croak "The name option must be supplied";
 
-    $self->{owner} = delete $args->{owner}
-      or croak "A " . __PACKAGE__ . " must have an owner";
+  $self->{owner} = delete $args->{owner}
+   or croak "A " . __PACKAGE__ . " must have an owner";
 
-    # Build our object
-    $self->{name} = $self->owner->_canonical_name( $name );
+  # Build our object
+  $self->{name} = $self->owner->_canonical_name( $name );
 
-    # Avoid circular references
-    weaken $self->{owner};
+  # Avoid circular references
+  weaken $self->{owner};
 
-    for my $opt ( qw(files recurse) ) {
-        $self->{_options}->{$opt} = delete $args->{$opt};
-    }
+  for my $opt ( qw(files recurse) ) {
+    $self->{_options}->{$opt} = delete $args->{$opt};
+  }
 
-    $self->_report_extra( $args );
+  $self->_report_extra( $args );
 }
 
 sub _read_dir {
-    my $self = shift;
-    my $dir  = shift;
+  my $self = shift;
+  my $dir  = shift;
 
-    opendir( my $dh, $dir ) or die "Can't read $dir ($!)";
-    my @files = map { File::Spec->catfile( $dir, $_ ) }
-      sort
-      grep { $_ !~ /^[.]{1,2}$/ } readdir( $dh );
-    closedir( $dh );
+  opendir( my $dh, $dir ) or die "Can't read $dir ($!)";
+  my @files = map { File::Spec->catfile( $dir, $_ ) }
+   sort
+   grep { $_ !~ /^[.]{1,2}$/ } readdir( $dh );
+  closedir( $dh );
 
-    return @files;
+  return @files;
 }
 
 sub _stat {
-    my $self = shift;
-    my $name = shift;
+  my $self = shift;
+  my $name = shift;
 
-    return stat $name;
+  return stat $name;
 }
 
 # Scan our target object
 sub _scan_object {
-    my $self = shift;
-    my $name = $self->name;
-    my %info;
+  my $self = shift;
+  my $name = $self->name;
+  my %info;
 
-    eval {
-        @info{@STAT_FIELDS} = $self->_stat( $name );
+  eval {
+    @info{@STAT_FIELDS} = $self->_stat( $name );
 
-        if ( defined $info{mode} && S_ISDIR( $info{mode} ) ) {
-            my $monitor = $self->owner;
+    if ( defined $info{mode} && S_ISDIR( $info{mode} ) ) {
+      my $monitor = $self->owner;
 
-            # Do directory specific things
-            if ( $self->{_options}->{files} ) {
+      # Do directory specific things
+      if ( $self->{_options}->{files} ) {
 
-                # Expand one level
-                $info{files} = [ map { $monitor->_make_relative( $_ ) }
-                      $self->_read_dir( $name ) ];
-            }
-            elsif ( $self->{_options}->{recurse} ) {
+        # Expand one level
+        $info{files} = [ map { $monitor->_make_relative( $_ ) }
+           $self->_read_dir( $name ) ];
+      }
+      elsif ( $self->{_options}->{recurse} ) {
 
-                # Expand whole directory tree
-                my @work = $self->_read_dir( $name );
-                while ( my $obj = shift @work ) {
-                    push @{ $info{files} },
-                      $monitor->_make_relative( $obj );
-                    if ( -d $obj ) {
+        # Expand whole directory tree
+        my @work = $self->_read_dir( $name );
+        while ( my $obj = shift @work ) {
+          push @{ $info{files} }, $monitor->_make_relative( $obj );
+          if ( -d $obj ) {
 
-                        # Depth first to simulate recursion
-                        unshift @work, $self->_read_dir( $obj );
-                    }
-                }
-            }
+            # Depth first to simulate recursion
+            unshift @work, $self->_read_dir( $obj );
+          }
         }
-    };
+      }
+    }
+  };
 
-    $info{error} = $@;
+  $info{error} = $@;
 
-    return \%info;
+  return \%info;
 }
 
 sub scan {
-    my $self = shift;
+  my $self = shift;
 
-    my $info    = $self->_scan_object;
-    my $name    = $self->name;
-    my @changes = ();
+  my $info    = $self->_scan_object;
+  my $name    = $self->name;
+  my @changes = ();
 
-    unless ( delete $self->{_info}->{virgin} ) {
+  unless ( delete $self->{_info}->{virgin} ) {
 
-        # Already done one scan, so now we compute deltas
-        my $change = File::Monitor::Delta->new(
-            {
-                object   => $self,
-                old_info => $self->{_info},
-                new_info => $info
-            }
-        );
+    # Already done one scan, so now we compute deltas
+    my $change = File::Monitor::Delta->new(
+      {
+        object   => $self,
+        old_info => $self->{_info},
+        new_info => $info
+      }
+    );
 
-        if ( $change->is_change ) {
-            $self->_make_callbacks( $change );
-            push @changes, $change;
-        }
+    if ( $change->is_change ) {
+      $self->_make_callbacks( $change );
+      push @changes, $change;
     }
+  }
 
-    $self->{_info} = $info;
+  $self->{_info} = $info;
 
-    return @changes;
+  return @changes;
 }
 
 1;
@@ -191,7 +190,7 @@ File::Monitor::Object - Monitor a filesystem object for changes.
 
 =head1 VERSION
 
-This document describes File::Monitor::Object version 0.10
+This document describes File::Monitor::Object version 1.00
 
 =head1 SYNOPSIS
 
